@@ -17,11 +17,11 @@
 import sys
 import os
 import re
-from calculate.lib.cl_template import TemplateFormat
+from ..cl_template import TemplateFormat
 import hashlib
 
-from calculate.lib.cl_lang import setLocalTranslate
-from calculate.lib.utils.files import (getProgPath, pathJoin, process, STDOUT,
+from ..cl_lang import setLocalTranslate
+from ..utils.files import (getProgPath, pathJoin, process, STDOUT,
                                        readFile, writeFile, listDirectory)
 
 _ = lambda x: x
@@ -76,10 +76,10 @@ class backgrounds(TemplateFormat):
 
     def getImageMD5(self, source, resolutions=()):
         if source:
-            data = readFile(source)
+            data = readFile(source, binary=True)
         else:
-            data = ""
-        return hashlib.md5(data+"\n".join(resolutions)).hexdigest()
+            data = b""
+        return hashlib.md5(data + "\n".join(resolutions).encode("UTF-8")).hexdigest()
 
     def setStretch(self, stretch):
         self.stretch = stretch
