@@ -132,7 +132,7 @@ class GPG():
                     if len(l.split(' ')) >= 12:
                         sig_data_ok = True
             if not p.success() or not goodsig or not sig_data_ok:
-                if b"No public key" in p.readerr():
+                if "No public key" in p.readerr():
                     raise GPGNoKey(p.readerr())
                 else:
                     raise GPGError(p.readerr())
