@@ -18,15 +18,15 @@ import os
 import sys
 from os import path
 from itertools import *
-from calculate.lib.datavars import (TableVariable, Variable, ReadonlyVariable,
+from ..datavars import (TableVariable, Variable, ReadonlyVariable,
                                     VariableError, ReadonlyTableVariable,
                                     FieldValue, HumanReadable)
-from calculate.lib.utils.files import (listDirectory, process, PIPE, pathJoin,
+from ..utils.files import (listDirectory, process, PIPE, pathJoin,
                                        readFileEx)
-from calculate.lib.utils.portage import (isPkgInstalled, RepositoryPath,
+from ..utils.portage import (isPkgInstalled, RepositoryPath,
                                     getInstalledAtom, getPortagePython)
-from calculate.lib.utils.common import cmpVersion
-from calculate.lib.datavars import DataVars
+from ..utils.common import cmpVersion
+from ..datavars import DataVars
 from itertools import dropwhile
 import re
 import contextlib
@@ -34,7 +34,7 @@ import multiprocessing
 from collections import namedtuple
 
 _ = lambda x: x
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
@@ -56,7 +56,7 @@ class VariableClEnvLocation(ReadonlyVariable):
     Aliases to ini files (from cl_env_data)
     """
     type = 'list'
-    value = list(zip(*_envData)[0])
+    value = list(list(zip(*_envData))[0])
 
 
 class VariableClEnvPath(Variable):
@@ -64,7 +64,7 @@ class VariableClEnvPath(Variable):
     Path to ini files (from cl_env_data)
     """
     type = 'list'
-    value = list(zip(*_envData)[1])
+    value = list(list(zip(*_envData))[1])
 
 
 class VariableClTemplateData(TableVariable):
@@ -111,16 +111,11 @@ class VariableClTemplateCltPath(ReadonlyVariable):
         """
         chroot = self.Get('cl_chroot_path')
         if "CONFIG_PROTECT" in os.environ:
-            protect_paths = ["/etc"] + filter(
-                lambda x: x.strip(),
-                os.environ["CONFIG_PROTECT"].split(" "))
+            protect_paths = ["/etc"] + [x for x in os.environ["CONFIG_PROTECT"].split(" ") if x.strip()]
         else:
             protect_paths = ["/etc", "/usr/share/X11/xkb", "var/lib/hsqldb",
                              "/usr/share/config"]
-        return filter(path.exists,
-                      map(lambda x: pathJoin(chroot, x),
-                          protect_paths))
-
+        return [x for x in [pathJoin(chroot, y) for y in protect_paths] if path.exists(x)]
 
 class VariableClRootPath(Variable):
     """
@@ -358,10 +353,8 @@ class VariableClWsdlAvailable(ReadonlyVariable):
                          if (x.endswith('site-packages') and
                              x.startswith('/usr/lib'))]
         ret_list = []
-        for module, modDir in chain(
-                *map(lambda x: map(lambda y: (path.basename(y), y),
-                                   listDirectory(x, True, True)),
-                     site_packages)):
+        for module, modDir in chain(*[((path.basename(y), y) for y 
+                in listDirectory(x, True, True)) for x in site_packages]):
             if path.exists(path.join(modDir, "wsdl_%s.py" % module)):
                 if not "calculate-%s" % module in ret_list:
                     ret_list.append("calculate-%s" % module)
@@ -377,7 +370,7 @@ class VariableClConfigProtectMask(ReadonlyVariable):
     def get(self):
         emerge_config = self.Get('cl_emerge_config')
         if emerge_config and "CONFIG_PROTECT_MASK" in emerge_config:
-            return emerge_config['CONFIG_PROTECT_MASK'].encode('utf-8').split()
+            return emerge_config['CONFIG_PROTECT_MASK'].split()
         display_env = process('/bin/bash', "-c", "source /etc/profile;env",
                               stdout=PIPE)
         for line in display_env:
@@ -398,7 +391,8 @@ class VariableClConfigProtect(ReadonlyVariable):
     def get(self):
         emerge_config = self.Get('cl_emerge_config')
         if emerge_config and "CONFIG_PROTECT" in emerge_config:
-            return emerge_config['CONFIG_PROTECT'].encode('utf-8').split()
+            return emerge_config['CONFIG_PROTECT'].split()
+            # return emerge_config['CONFIG_PROTECT'].encode('utf-8').split()
         display_env = process('/bin/bash', "-c", "source /etc/profile;env",
                               stdout=PIPE)
         for line in display_env:
@@ -466,11 +460,11 @@ class VariableClPkgdir(ReadonlyVariable):
     def get(self):
         emerge_config = self.Get('cl_emerge_config')
         if emerge_config and "PKGDIR" in emerge_config:
-            return emerge_config['PKGDIR'].encode('utf-8')
+            # return emerge_config['PKGDIR'].encode('utf-8')
+            return emerge_config['PKGDIR']
         else:
             emerge_info = self.Get('cl_emerge_info')
-            for line in filter(lambda x: x.startswith("PKGDIR="),
-                               emerge_info):
+            for line in (x for x in emerge_info if x.startswith("PKGDIR=")):
                 return line.partition("=")[2].strip('\n"\'')
         return ""
 
@@ -484,14 +478,12 @@ class VariableClFeatures(ReadonlyVariable):
     def get(self):
         emerge_config = self.Get('cl_emerge_config')
         if emerge_config and "FEATURES" in emerge_config:
-            return filter(
-                None, emerge_config['FEATURES'].encode('utf-8').split())
+            # return filter(None, emerge_config['FEATURES'].encode('utf-8').split())
+            return [x for x in emerge_config['FEATURES'].split() if x]
         else:
             emerge_info = self.Get('cl_emerge_info')
-            for line in filter(lambda x: x.startswith("FEATURES="),
-                               emerge_info):
-                return filter(
-                    None, line.partition("=")[2].strip('\n"\'').split())
+            for line in (x for x in emerge_info if x.startswith("FEATURES=")):
+                return [x for x in line.partition("=")[2].strip('\n"\'').split() if x]
         return ""
 
 
@@ -503,7 +495,8 @@ class VariableClDistdir(ReadonlyVariable):
     def get(self):
         emerge_config = self.Get('cl_emerge_config')
         if emerge_config and "DISTDIR" in emerge_config:
-            return emerge_config['DISTDIR'].encode('utf-8')
+            # return emerge_config['DISTDIR'].encode('utf-8')
+            return emerge_config['DISTDIR']
         return "/var/calculate/remote/distfiles"
 
 
@@ -525,13 +518,11 @@ class VariableClRepositoryData(ReadonlyTableVariable):
         return re_block.findall(text)
 
     def from_portdir_vars(self, info):
-        for line in filter(lambda x: x.startswith("PORTDIR="),
-                           info):
+        for line in (x for x in info if x.startswith("PORTDIR=")):
             yield ["gentoo", line.partition("=")[2].strip('\n"\'')]
 
         self.Get('cl_emerge_info')
-        for line in filter(lambda x: x.startswith("PORTDIR_OVERLAY="),
-                           info):
+        for line in (x for x in info if x.startswith("PORTDIR_OVERLAY=")):
             for i in ([path.basename(x), x]
                       for x in line.partition("=")[2].strip('\n"\'').split(' ')
                       if x):
@@ -540,8 +531,9 @@ class VariableClRepositoryData(ReadonlyTableVariable):
     def get(self, hr=HumanReadable.No):
         emerge_config = self.Get('cl_emerge_config')
         if emerge_config and "PKGDIR" in emerge_config:
-            return [[repo.name.encode('UTF-8'), repo.location.encode('UTF-8')]
+            tmp = [[repo.name, repo.location]
                     for repo in emerge_config.repositories]
+            return tmp
         else:
             info = self.Get("cl_emerge_info")
             if self.portage_ver_ge("2.2.18"):
@@ -603,7 +595,7 @@ def stderr_devnull():
         sys.stderr = oldstderr
 
 
-class PortageConfigWrapper(object):
+class PortageConfigWrapper():
     def __init__(self):
         self._dict = {}
         self.repositories = []
@@ -677,7 +669,7 @@ class VariableClEmergeConfig(ReadonlyVariable):
                 c = PortageConfigWrapper.getconfig_chroot(self.systemRoot)
             c.__str__ = lambda self: "EmergeConfig"
             return c
-        except Exception:
+        except Exception as e:
             pass
         return ""
 
@@ -690,11 +682,11 @@ class VariableClEmergeDefaultOpts(ReadonlyVariable):
     def get(self):
         emerge_config = self.Get('cl_emerge_config')
         if emerge_config:
-            return emerge_config['EMERGE_DEFAULT_OPTS'].encode('UTF-8')
+            # return emerge_config['EMERGE_DEFAULT_OPTS'].encode('UTF-8')
+            return emerge_config['EMERGE_DEFAULT_OPTS']
         else:
             emerge_info = self.Get('cl_emerge_info')
-            for line in filter(lambda x: x.startswith("EMERGE_DEFAULT_OPTS="),
-                               emerge_info):
+            for line in (x for x in emerge_info if x.startswith("EMERGE_DEFAULT_OPTS=")):
                 key, op, value = line.partition('=')
                 for quote in ("'", '"'):
                     if value.startswith(quote):
@@ -733,8 +725,7 @@ class VariableClTemplatesLocate(Variable):
             return vals + ['clt']
 
     def choice(self):
-        return map(lambda x: (x, self.descriptionMap.get(x, x)),
-                   self.get())
+        return [(x, self.descriptionMap.get(x, x)) for x in self.get()]
 
 
 class VariableClTemplatePathUse(ReadonlyVariable):
